@@ -1,12 +1,12 @@
 package DBIx::Class::EncodedColumn::Crypt::Passphrase::Argon2;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Crypt::Passphrase::Argon2 backend
+# ABSTRACT: Crypt::Passphrase::Argon2 backend - DEPRECATED
 
 use strict;
 use warnings;
 
-our $VERSION = '0.0107';
+our $VERSION = '0.0107_1';
 
 use Encode qw(encode_utf8);
 use Crypt::Passphrase::Argon2 ();
@@ -56,11 +56,11 @@ sub make_check_sub {
 
 =head1 NAME
 
-DBIx::Class::EncodedColumn::Crypt::Passphrase::Argon2 - Crypt::Passphrase::Argon2 backend
+DBIx::Class::EncodedColumn::Crypt::Passphrase::Argon2 - Crypt::Passphrase::Argon2 backend - DEPRECATED
 
 =head1 VERSION
 
-version 0.0107
+version 0.0107_1
 
 =head1 SYNOPSIS
 
@@ -86,6 +86,8 @@ version 0.0107
 
 =head1 DESCRIPTION
 
+* DEPRECATED *
+
 Use L<Crypt::Passphrase::Argon2> for an encoded password column.
 
 =head1 ENCODE ARGUMENTS
